#!/bin/sh

name="postfix"
title="Postfix"
package="postfix"
version="2.0.10"
build="2"
noarch="n"
build_info="Standard build."

info="The Postfix MTA."
desc="It is Wietse Venema's mailer that started life as an
alternative to the widely-used Sendmail program.
Postfix attempts to be fast, easy to administer, and
secure, while at the same time being sendmail
compatible enough to not upset existing users. Thus,
the outside has a sendmail-ish flavor, but the inside
is completely different.
This software was formerly known as VMailer. It was
released by the end of 1998 as the IBM Secure Mailer.
From then on it has lived on as Postfix."
category="net/servers/mta"
environment="console/text"
contact="$name@packages.packware.one.pl"
vendor="The Packware Project"
vendor_id="pw"

requires=""
obsoletes=""
conflicts=""

docs_source="0README,COMPATIBILITY,COPYRIGHT,HISTORY,INSTALL,LICENSE,PORTING,RELEASE_NOTES*,README_FILES,html"
docs_cwd=""

strip_bin="y"
reset_own="y"
reset_dir="y"
reset_fil="y"
delete_cat="y"

. /usr/src/tgz/lib/builder.defs

add_source ftp://ftp.porcupine.org/mirrors/postfix-release/official/$name-$version.tar.gz

apply_patch mysql

[ -d /usr/lib/sasl  ] && have_sasl="sasl"
[ -d /usr/lib/sasl2 ] && have_sasl="sasl2"

if [ ! "$have_sasl" = "" ]; then

    verbose "Cyrus SASL has been detected on this system."
    verbose "Do you want Postfix to support SASL?"
    yes_or_no with_sasl y

fi

if [ "$with_sasl" = "y" ]; then

    apply_patch $have_sasl
    package_suffix $have_sasl
    build_info " With SASL."

fi

parent_package="$package"
write_info main

cd $src1

do_make

sh postfix-install -non-interactive \
    install_root=$pkg_main \
    manpage_directory=/usr/man \
    sample_directory=/usr/doc/$name-$version/samples \
    readme_directory=/usr/doc/$name-$version/README_FILES

rm -rf $doc_dir/README_FILES

sed 's}\(\.[0-9]\)}\1.gz}' $pkg_main/etc/postfix/postfix-files | \
sed 's}\$config_directory/aliases}/etc/aliases}' > \
    $tmp/postfix-files.new
cat $tmp/postfix-files.new > $pkg_main/etc/postfix/postfix-files

for i in access canonical main.cf master.cf pcre_table regexp_table \
	relocated transport virtual; do
    mv -f $pkg_main/etc/postfix/$i $pkg_main/etc/postfix/$i.new
done

mv -f $pkg_main/etc/postfix/aliases $pkg_main/etc/aliases.new

if [ "$with_sasl" = "y" ]; then

    cat $src_pkg/sasl.conf >> $pkg_main/etc/postfix/main.cf.new
    copy $src_pkg/smtpd-$have_sasl.conf $pkg_main/usr/lib/$have_sasl smtpd.conf

fi

copy $src_pkg/rc.postfix $pkg_main/etc/rc.d
chmod a+x $pkg_main/etc/rc.d/rc.postfix

make_docs

rm -f $doc_dir/html/Makefile.in

make_package main

clean_up

# $Log: postfix.builder,v $
# Revision 1.24  2003/06/03 20:58:25  swiergot
# - Build 2.
#
# Revision 1.23  2003/06/03 20:52:18  swiergot
# - Added MySQL support.
#
# Revision 1.22  2003/06/03 13:28:26  swiergot
# - Build 1.
#
# Revision 1.21  2003/06/03 13:23:53  swiergot
# - Version 2.0.10.
#
# Revision 1.20  2003/04/20 19:49:02  swiergot
# - Build 1.
#
# Revision 1.19  2003/04/20 19:42:23  swiergot
# - Rebuild against cyrus-sasl-2.1.13.
#
# Revision 1.18  2003/04/20 19:06:04  swiergot
# - Version 2.0.9.
#
# Revision 1.17  2003/03/23 08:25:45  swiergot
# - Build 6.
#
# Revision 1.16  2003/03/23 00:09:51  swiergot
# - Fixed smtpd-*.conf files. Now SMTP AUTH should finally work.
#
# Revision 1.15  2003/03/22 23:19:50  swiergot
# - Fixed sasl.conf.
#
# Revision 1.14  2003/03/22 23:13:06  swiergot
# - Put smtpd.conf in usr/lib/sasl or usr/lib/sasl2, not etc/sasl.
#
# Revision 1.13  2003/03/22 16:51:47  swiergot
# - Fixed SASL patches.
#
# Revision 1.12  2003/03/22 15:48:29  swiergot
# - Install different smtpd.conf according to present SASL version.
# - Set package_suffix sasl2 if we're building against SASL 2.
#
# Revision 1.11  2003/03/22 11:40:09  swiergot
# - Fixed sasl.conf.
# - Added smtpd.conf that will be put in etc/sasl if SASL is supported.
#
# Revision 1.10  2003/03/22 08:46:39  swiergot
# - Build 5.
#
# Revision 1.9  2003/03/22 08:34:17  swiergot
# - Fixed regexp that fixes the aliases file location in postfix-files.
#
# Revision 1.8  2003/03/21 22:25:19  swiergot
# - Build 4.
#
# Revision 1.7  2003/03/21 22:17:04  swiergot
# - Don't run usr/bin/newaliases in the install script.
# - Fix the aliases file path in postfix-files.
#
# Revision 1.6  2003/03/21 21:54:56  swiergot
# - Build 3.
#
# Revision 1.5  2003/03/21 21:43:54  swiergot
# - Added support for Cyrus SASL.
#
# Revision 1.4  2003/03/21 10:31:21  swiergot
# - Build 2.
#
# Revision 1.3  2003/03/21 10:24:08  swiergot
# - Moved etc/postfix/aliases.new to etc/aliases.new.
# - Run usr/bin/newaliases at the end of script.postinst.
#
# Revision 1.2  2003/03/20 19:59:30  swiergot
# - Build 1.
#
# Revision 1.1  2003/03/20 16:39:37  swiergot
# - Initial release.
# - Version 2.0.7.
#
